package com.ruoyi.frequency.like.service;

import java.util.List;

import com.ruoyi.controller.req.LikeReq;
import com.ruoyi.frequency.like.entity.Like;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

/**
 * 点赞(新闻,活动)Service接口
 * 
 * @author liwenlong
 * @date 2024-04-16
 */
public interface LikeService extends IService<Like>
{
    /**
     * 查询点赞(新闻,活动)
     * 
     * @param id 点赞(新闻,活动)主键
     * @return 点赞(新闻,活动)
     */
    public Like selectLikeById(Long id);

    /**
     * 查询点赞(新闻,活动)列表
     * 
     * @param like 点赞(新闻,活动)
     * @return 点赞(新闻,活动)集合
     */
    public List<Like> selectLikeList(Like like);

    /**
     * 新增点赞(新闻,活动)
     * 
     * @param like 点赞(新闻,活动)
     * @return 结果
     */
    public int insertLike(Like like);

    /**
     * 修改点赞(新闻,活动)
     * 
     * @param like 点赞(新闻,活动)
     * @return 结果
     */
    public int updateLike(Like like);

    /**
     * 批量删除点赞(新闻,活动)
     * 
     * @param ids 需要删除的点赞(新闻,活动)主键集合
     * @return 结果
     */
    public int deleteLikeByIds(Long[] ids,Integer delFlag);

    /**
     * 点赞
     * @param req
     * @param userVo
     * @return
     */
    ResponseData like(LikeReq req, UserVo userVo);
}
